@@ -81,7 +81,8 @@ List pepmarginallikelihoodc(arma::mat x, NumericVector y, arma::mat xnew, bool p
  for (int i = 0; i < s; ++i){ // for point (i+1)
                               // compute function value
   double temp = (b1-1)*log(sq[i])+(c-b1-1)*log(1-sq[i])-a0*log(1-sq[i]*1/(1+delta*R))+an1*log(1-sq[i]*1/(1+delta));  
-  if (arma::is_finite(temp)){ // if this is finite
+// if (arma::is_finite(temp)){ // if this is finite
+  if (std::isfinite(temp)){ // if this is finite
    vsq[k] = temp;    // add it to the vector
    k = k+1;
   }                  // end if
